<?php
session_start();

if(!file_exists('protected' . DIRECTORY_SEPARATOR . 'configuration.php')){
    die('No configuration file found');
}

//Include configuration file
include_once('protected' . DIRECTORY_SEPARATOR . 'configuration.php');
$configuration = new Configuration();

//Include autoloader
include_once('autoloader.php');

/**
 * Define shortcut for translate function
 * @param $value
 * @return mixed
 */
function __($value){
    return \ImageRecycle\Standalone\Translator::translate($value);
}

if(!isset($_SESSION['IR_CONNECTED']) || $_SESSION['IR_CONNECTED']!==true){
    header('HTTP/1.0 403 Forbidden');
}

//If nothing to do return;
if(!isset($_POST['action'])){
    die();
}

$db = new ImageRecycle\Standalone\Database();

switch($_POST['action']) {
    case 'getImages':
        $limit = 10;
        $escape = array();

        if (isset($_POST['page'])) {
            $page = $_POST['page'];
        } else {
            $page = 0;
        }
        if (isset($_POST['pageSize'])) {
            $pageSize = (int)$_POST['pageSize'];
        } else {
            $pageSize = 10;
        }

        if (in_array($pageSize, array(10,20,50,100))) {
            $limit = $pageSize;
        }

        $query = 'SELECT * FROM images ';

        $querySearch = '';
        if (trim($_POST['search'])) {
            $querySearch = 'WHERE file LIKE :search ';
            $escape[':search'] = '%' . trim($_POST['search']) . '%';
        }

        $queryOrder = 'ORDER BY file ';

        $queryLimit = 'LIMIT ' . (int)($page * $limit) . ',' . (int)$limit . ' ';

        $stmt = $db->prepare($query . ' ' . $querySearch . ' ' . $queryOrder . ' ' . $queryLimit);
        foreach ($escape as $variable => $value) {
            $stmt->bindValue($variable, $value, SQLITE3_TEXT);
        }

        $db->setResult($stmt->execute());
        $images = $db->getObjectList();

        //Get total of current query
        $stmt = $db->prepare('SELECT COUNT(*) as result FROM images ' . $querySearch);
        foreach ($escape as $variable => $value) {
            $stmt->bindValue($variable, $value, SQLITE3_TEXT);
        }

        $db->setResult($stmt->execute());
        $count = $db->getObject();
        $count = ceil($count->result / $limit);

        echo json_encode(array('images' => $images, 'page' => $page, 'total_pages' => $count));
        die();
        break;

    case 'sync':
        \ImageRecycle\Standalone\Images::sync();
        break;
    case 'optimize':
        $idImage = $_POST['id'];

        $result = \ImageRecycle\Standalone\Images::optimize($idImage);

        echo json_encode($result);
        die();
    case 'revert':
        $idImage = $_POST['id'];
        $db->query('SELECT * FROM images WHERE id='.(int)$idImage);
        $image = $db->getObject();
        
        $api = new ImageRecycle\Standalone\Api($configuration->api_key,$configuration->api_secret);

        //Local file
        $file = dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . $image->file;

        //Check if file to optimize still exists
        if(!is_file($file)){
            echo json_encode(array('status'=>'error','response'=>__('Local file not found')));
            die();
        }
        try{
            $response = $api->getImage($image->api_id);
        }catch (Exception $e){
            echo json_encode(array('status'=>'error','response'=>$e->getMessage()));
            die();
        }

        //Download image
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, $response->origin_url);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $data = curl_exec($ch);

        //Check http response
        $http_code = curl_getinfo($ch,CURLINFO_HTTP_CODE);
        if($http_code!='200'){
            echo json_encode(array('status'=>'error','response'=>__('Downloading file from ImageRecycle failed')));
            die();
        }

        curl_close($ch);

        //Replace file content with original one
        if(!is_writable($file)){
            echo json_encode(array('status'=>'error','response'=>__('Write original content to file is not authorized, please check file permissions')));
            die();
        }
        file_put_contents($file,$data);
        
        //Update database
        $stmt = $db->prepare('UPDATE images SET api_id=NULL, size_before=:size_before, size_after=NULL, expiration_date=NULL, status="R" WHERE id=:id');
        $stmt->bindValue(':id',$idImage,SQLITE3_TEXT);
        $stmt->execute();

        echo json_encode(array('status'=>'success','response'=>$response));
        die();
    case 'optimizeStatus':
        $runnning = false;

        //Check running status
        $db->query('SELECT * FROM options WHERE name="optimization_running"');
        $result = $db->getObject();
        if($result->value=='1'){
            //If running check if it's not stuck on an image
            $db->query('SELECT * FROM options WHERE name="optimization_last_image"');
            $result = $db->getObject();
            if($result->value + 60 * 5 > time()){
                $runnning = true;
            }
        }

        if($runnning===false){
            echo json_encode(array('status'=>'stopped'));
            die();
        }

        $db->query('SELECT * FROM options WHERE name IN ("optimization_total","optimization_errors","optimization_optimized")');
        $results = $db->getObjectList();
        $response = array();
        foreach ($results as $result){
            $response[$result->name] = $result->value;
        }

        echo json_encode(array('status'=>'running','response'=>$response));
        die();
    case 'stopAutoOptimize':
        touch('protected/.cronstop');
        die();
}