<?php

namespace ImageRecycle\Standalone;


class Images
{

    public static function sync(){
        $configuration = new \Configuration();
        $db = new Database();

        //First delete all files that are not optimized or reverted
        $db->exec('DELETE FROM images WHERE status=""');

        if (!$configuration->folders) {
            $folders = array(DIRECTORY_SEPARATOR);
        }else{
            $folders = explode(',', $configuration->folders);
        }

        $allowedExt = array();

        if($configuration->optimization_jpg!=='none'){
            $allowedExt[] = 'jpg';
            $allowedExt[] = 'jpeg';
        }

        if($configuration->optimization_png!=='none'){
            $allowedExt[] = 'png';
        }

        if($configuration->optimization_gif!=='none'){
            $allowedExt[] = 'gif';
        }

        if($configuration->optimization_pdf!=='none'){
            $allowedExt[] = 'pdf';
        }

        $directoryBase = realpath(dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..');

        $files = \ImageRecycle\Standalone\Filesystem::listFiles($directoryBase,$allowedExt,IR_ITERATOR_ONLYFILE);

        //Start transaction to write on disk only when loop is finished to speed up things
        $db->exec('BEGIN TRANSACTION');

        foreach ($files as $filename) {
            set_time_limit(30);

            //Check if this is a folder we sync
            $continue = false;
            foreach ($folders as $folder){
                //If no folder is set we accept all
                if($folder===DIRECTORY_SEPARATOR){
                    $continue = true;
                    break;
                }

                //Check if file path starts with one of the included folders
                if(strpos($filename,DIRECTORY_SEPARATOR.$folder)===0){
                    $continue = true;
                    break;
                }
            }
            if($continue===false){
                continue;
            }

            $db->exec('INSERT OR IGNORE INTO images (file,size_before,status) VALUES ("'.$filename.'",'.filesize($directoryBase.$filename).',"")');
        }

        //Save to disk
        $db->exec('END TRANSACTION');

        $installer = new \ImageRecycle\Standalone\Installer();
        $installer->writeConfigFile(array('last_sync'=>time()));
    }

    public static function optimize($idImage){
        $configuration = new \Configuration();
        $db = new Database();

        $db->query('SELECT * FROM images WHERE id='.(int)$idImage);
        $image = $db->getObject();

        if($image->status==='O'){
            return array('status'=>'error','response'=>__('This file is already optimized'));
        }

        $api = new Api($configuration->api_key,$configuration->api_secret);

        //Local file
        $file = dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . $image->file;

        //Check if file to optimize still exists
        if(!is_file($file)){
            return array('status'=>'error','response'=>__('Local file not found'));
        }

        //Check if image is in the optimized folders
        if (!$configuration->folders) {
            $folders = array(DIRECTORY_SEPARATOR);
        }else{
            $folders = explode(',', $configuration->folders);
        }

        $continue = false;
        foreach ($folders as $folder){
            //If no folder is set we accept all
            if($folder===DIRECTORY_SEPARATOR){
                $continue = true;
                break;
            }

            //Check if file path starts with one of the included folders
            if(strpos($image->file,DIRECTORY_SEPARATOR.$folder)===0){
                $continue = true;
                break;
            }
        }
        if($continue===false){
            return array('status'=>'error','response'=>__('File is not in the selected folders'));
        }

        //Get params for this file
        switch (strtolower(pathinfo($image->file,PATHINFO_EXTENSION))){
            case 'png':
                $ext = 'png';
                break;
            case 'jpg':
            case 'jpeg':
                $ext = 'jpg';
                break;
            case 'gif':
                $ext = 'gif';
                break;
            case 'pdf':
                $ext = 'pdf';
                break;
            default:
                return array('status'=>'error','response'=>__('File extension not supported'));
        }

        if($configuration->{'optimization_'.$ext}==='none'){
            return  array('status'=>'error','response'=>__('Optimization is disabled in configuration file'));
        }
        $params = array();
        $params['compression_type'] = $configuration->{'optimization_'.$ext};

        $params['preserve_metas'] = array();
        if($configuration->preserve_meta_orientation){
            $params['preserve_metas'][] = 'orientation';
        }
        if($configuration->preserve_meta_color_profile){
            $params['preserve_metas'][] = 'icc';
        }
        if($configuration->preserve_meta_copyright){
            $params['preserve_metas'][] = 'copyright';
        }
        if($configuration->preserve_meta_datetime){
            $params['preserve_metas'][] = 'datetime';
        }
        if($configuration->preserve_meta_location){
            $params['preserve_metas'][] = 'location';
        }

        try{
            $response = $api->uploadFile($file,$params);
        }catch (Exception $e){
            return array('status'=>'error','response'=>$e->getMessage());
        }

        //Download image
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, str_replace(' ', '%20', $response->optimized_url));
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $data = curl_exec($ch);

        //Check http response
        $http_code = curl_getinfo($ch,CURLINFO_HTTP_CODE);
        if($http_code!='200'){
            return array('status'=>'error','response'=>__('Downloading file from ImageRecycle failed'));
        }

        curl_close($ch);

        //Replace file content with optimized one
        if(!is_writable($file)){
            return array('status'=>'error','response'=>__('Write original content to file is not authorized, please check file permissions'));
        }
        file_put_contents($file,$data);

        //Update database
        $stmt = $db->prepare('UPDATE images SET api_id=:api_id, size_before=:size_before, size_after=:size_after, optimization_date=:optimization_date, expiration_date=:expiration_date, status="O" WHERE id=:id');
        $stmt->bindValue(':api_id',$response->id,SQLITE3_INTEGER);
        $stmt->bindValue(':size_before',$response->size_before,SQLITE3_INTEGER);
        $stmt->bindValue(':size_after',$response->size_after,SQLITE3_INTEGER);
        $stmt->bindValue(':optimization_date',date('Y-m-d H:i:s'),SQLITE3_TEXT);
        $stmt->bindValue(':expiration_date',$response->expiration_date,SQLITE3_TEXT);
        $stmt->bindValue(':id',$idImage,SQLITE3_TEXT);
        $stmt->execute();

        $db->close();

        return array('status'=>'success','response'=>$response);
    }

}