<?php
/**
 * Installer class for standalone script
 */

namespace ImageRecycle\Standalone;


class Installer
{
    public function checkRequirements(){
        $requirements = array();
        $requirements['php'] = version_compare(PHP_VERSION, '5.3.0') >= 0;
        $requirements['curl'] = function_exists('curl_init');
        $requirements['sqlite3'] = class_exists('SQLite3');
        $requirements['protected_folder_writable'] = is_writable(dirname(__FILE__) . DIRECTORY_SEPARATOR .'..' . DIRECTORY_SEPARATOR . 'protected');
        $requirements['configuration_file_writable'] = is_writable(dirname(__FILE__) . DIRECTORY_SEPARATOR .'..' . DIRECTORY_SEPARATOR . 'protected'. DIRECTORY_SEPARATOR . 'configuration.php');
        
        return $requirements;
    }


    public function writeConfigFile($data){
        $configuration = new \Configuration();

        $content = '<?php'.PHP_EOL.
                    'class Configuration'.PHP_EOL.
                    '{'.PHP_EOL;
        foreach (get_object_vars($configuration) as $variable => $value){
            $content .=  '    public $' . $variable . ' = ' ;
            if(isset($data[$variable])){
                $content .= '"' . $data[$variable] . '"';
            }else{
                $content .= '"' . $value . '"';
            }
            $content .= ';' . PHP_EOL;
        }
        $content .= '}';

        if(file_put_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'protected' . DIRECTORY_SEPARATOR .'configuration.php',$content)){
            return true;
        }
        return false;
    }

    public function installDatabase($dbName){
        $dbFile = dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' .DIRECTORY_SEPARATOR . 'protected' . DIRECTORY_SEPARATOR . $dbName . '.db';
        if(!file_exists($dbFile)){
            $database = new Database($dbFile);
            //Create images table
            $database->exec('
                    CREATE TABLE images (
                        id INTEGER PRIMARY KEY AUTOINCREMENT, 
                        file TEXT UNIQUE NOT NULL, 
                        api_id INTEGER, 
                        size_before INTEGER, 
                        size_after INTEGER,
                        optimization_date TEXT,
                        expiration_date TEXT,
                        token TEXT,
                        status CHAR(1)
                    )');

            //Create configuration table
            $database->exec('
                    CREATE TABLE options (
                        id INTEGER PRIMARY KEY AUTOINCREMENT, 
                        name TEXT UNIQUE NOT NULL, 
                        value TEXT
                    )');
            //Set default values
            $database->exec('INSERT INTO options ("name","value") VALUES ("optimization_running","0")');
            $database->exec('INSERT INTO options ("name","value") VALUES ("optimization_total","0")');
            $database->exec('INSERT INTO options ("name","value") VALUES ("optimization_optimized","0")');
            $database->exec('INSERT INTO options ("name","value") VALUES ("optimization_errors","0")');
            $database->exec('INSERT INTO options ("name","value") VALUES ("optimization_last_image","0")');

            $error = $database->lastErrorMsg();
        }
    }

    public function checkUpdate(){
        //Only check one time per day
        $configuration = new \Configuration();
        if($configuration->last_update_check + 60 * 60 * 24 > time()){
            return;
        }

        //Get latest version informations
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, 'https://www.imagerecycle.com/standalone_update.json');
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);

        $data = curl_exec($ch);
        $data = json_decode($data);

        //Check http response
        $http_code = curl_getinfo($ch,CURLINFO_HTTP_CODE);
        if($http_code!='200' || $data===false){
            return;
        }
        curl_close($ch);

        //Set the last check
        $config = array('last_update_check'=>time());
        if(version_compare(IR_VERSION,$data->version)===-1){
            $config['update_version'] = $data->version;
        }
        $this->writeConfigFile($config);
    }
    public function update(){
        //Get latest version informations
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, 'https://www.imagerecycle.com/standalone_update.json');
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);

        $data = curl_exec($ch);
        $data = json_decode($data);

        //Check http response
        $http_code = curl_getinfo($ch,CURLINFO_HTTP_CODE);
        if($http_code!='200' || $data===false){
            return false;
        }
        curl_close($ch);

        if(version_compare(IR_VERSION,$data->version)===-1){
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
            curl_setopt($ch, CURLOPT_HEADER, 0);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_URL, $data->url);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);

            $data = curl_exec($ch);

            //Check http response
            $http_code = curl_getinfo($ch,CURLINFO_HTTP_CODE);
            if($http_code!='200' || $data===false){
                return false;
            }
            curl_close($ch);

            $tmpFile = dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'tmp' . DIRECTORY_SEPARATOR . 'update.zip';
            if(!file_put_contents($tmpFile,$data)){
                return false;
            }

            $zip = new \ZipArchive();
            if(!$zip->open($tmpFile)){
                return false;
            }

            if(!$zip->extractTo(dirname(__FILE__) . DIRECTORY_SEPARATOR . '..'  )){
                return false;
            }
            return true;
        }

    }
}