<div class="imageListing">
    <p class="right">
        <a class="waves-effect waves-light btn" id="sync"><?php _e('Sync images'); ?></a>
        <a class="waves-effect waves-light btn" <?php echo $optimizationRunning ? 'style="display: none;"' : ''; ?>
           id="optimizeAll"><?php _e('Optimize all'); ?></a>
        <a class="waves-effect waves-light btn" <?php echo !$optimizationRunning ? 'style="display: none;"' : ''; ?>
           id="stopOptimizeAll"><?php _e('Stop background optimization'); ?> <span></span></a>
    </p>

    <div class="row">
        <div class="input-field col s6">
            <?php _e('Filter by filename'); ?> : <input type="text" id="search"
                                                        placeholder="<?php _e('Start typing to filter'); ?>"/>
        </div>
    </div>
    <table id="tableImages" class="striped">
        <thead>
        <tr>
            <th data-field="file"><?php _e('File'); ?></th>
            <th data-field="size_before"><?php _e('Size before'); ?></th>
            <th data-field="size_after"><?php _e('Size after'); ?></th>
            <th data-field="status"><?php _e('Status'); ?></th>
            <th data-field="action"><?php _e('Actions'); ?></th>
        </tr>
        </thead>
        <tbody>
        </tbody>
    </table>
    <ul class="pagination center">
        <li class="waves-effect disabled previous"><a href="#!"><i class="material-icons">chevron_left</i></a></li>
        <li><?php _e('Page'); ?> : <span id="page-number"></span></li>
        <li class="waves-effect disabled next"><a href="#!"><i class="material-icons">chevron_right</i></a></li>
        <li>
            <select class="pageSize" id="pageSize" name="pageSize">
                <option value="10">10</option>
                <option value="20">20</option>
                <option value="50">50</option>
                <option value="100">100</option>
            </select>
        </li>
    </ul>

</div>

<script id="images-template" type="text/x-handlebars-template">
    {{#each images}}
    <tr data-id="{{id}}" data-status="{{status}}">
        <td data-col="file" ><p class="tooltip limited-text" data-title="{{file}}">{{limitText file}}</p></td>
        <td data-col="size_before">{{bytesToSize size_before}}</td>
        <td data-col="size_after">{{bytesToSize size_after}}</td>
        <td data-col="status">{{status status}}</td>
        <td><a href="#" class="btn action {{statusClass status}}">{{optimizeBtn status}}</a></td>
    </tr>
    {{/each}}
</script>

<script>
    preloader = '<div class="preloader-wrapper small active" style="vertical-align:bottom;"> <div class="spinner-layer spinner-green-only">        <div class="circle-clipper left">        <div class="circle"></div>        </div><div class="gap-patch"        <div class="circle"></div>        </div><div class="circle-clipper right">        <div class="circle"></div>        </div>        </div>        </div>';

    //Custom helpers
    Handlebars.registerHelper('statusClass', function (status) {
        if (status === 'O') return "revert";
        return 'optimize';
    });

    Handlebars.registerHelper('bytesToSize', function (bytes) {
        return bytesToSize(bytes);
    });

    Handlebars.registerHelper('status', function (status) {
        if (status === 'O') return "<?php _e('Optimized'); ?>";
        if (status === 'R') return "<?php _e('Reverted'); ?>";
        return '';
    });

    Handlebars.registerHelper('limitText', function (file) {
        if (file.length > 60) {
            var start = file.length - 60;
            return "..." + file.substring(start);
        }
        return file;
    });

    Handlebars.registerHelper('optimizeBtn', function (status) {
        if (status === 'O') return "<?php _e('Revert'); ?>";
        return "<?php _e('Optimize'); ?>";
    });

    //Generate images templates
    var sourceImages = $("#images-template").html();
    var templateImages = Handlebars.compile(sourceImages);

    $('document').ready(function () {

        // setup tooltip to display full file name
        initQtip = function() {
            $('.tooltip').qtip({ // Grab some elements to apply the tooltip to
                content: {
                    attr: 'data-title'
                },
                position: {
                    target:"mouse"
                }
            });

        };

        //Synchronize new images
        $('#sync').click(function (e) {
            e.preventDefault();
            var $that = $(this);
            $that.addClass('disabled');

            $('#tableImages tbody').html('<tr class="center"> <td colspan="7">' + preloader + '  <?php _e('Please wait while syncing all images'); ?></td></tr>');

            $.ajax({
                url: './ajax.php',
                method: 'POST',
                data: {
                    action: 'sync'
                },
                success: function (data) {
                    getImages();
                },
                complete: function () {
                    $that.removeClass('disabled');
                }
            });
        });

        $('#optimizeAll').click(function (e) {
            e.preventDefault();
            $.ajax({
                url: './cron.php',
                method: 'POST',
                data: {
                    token: '<?php echo $configuration->cron_token; ?>'
                },
                complete: function () {
                    Materialize.toast("<?php _e('Background optimization has been started'); ?>", 4000);
                    $('#stopOptimizeAll').show();
                    $('#optimizeAll').hide();
                    checkOptimizationStatus();
                }
            });
        });

        $('#stopOptimizeAll').click(function (e) {
            e.preventDefault();
            $.ajax({
                url: './ajax.php',
                method: 'POST',
                data: {
                    action: 'stopAutoOptimize'
                },
                complete: function () {
                    Materialize.toast("<?php _e('Background optimization has been stopped'); ?>", 4000);
                    $('#stopOptimizeAll').hide();
                    $('#optimizeAll').show();
                    clearInterval(window.optimizeAllInterval);
                    delete window.optimizeAllInterval;
                }
            });
        });

        //Load the list of images in table
        getImages = function (page) {
            if (page === undefined) {
                var page = 0;
            }
            var pageSize = $('#pageSize').val() ;
            $.ajax({
                url: './ajax.php',
                method: 'POST',
                data: {
                    action: 'getImages',
                    page: page,
                    pageSize: pageSize,
                    search: $('#search').val()
                },
                success: function (data) {
                    images = JSON.parse(data);

                    var html = templateImages(images);
                    $('#tableImages tbody').html(html);
                    bindOptimizeClick();

                    //init tooltip
                    initQtip();

                    if (images.page == '0') {
                        $('.pagination .previous').addClass('disabled');
                    } else {
                        $('.pagination .previous').removeClass('disabled');
                    }
                    $('.pagination .previous').attr('data-page', parseInt(images.page) - 1);

                    if (parseInt(images.page) + 1 < parseInt(images.total_pages)) {
                        $('.pagination .next').removeClass('disabled');
                    } else {
                        $('.pagination .next').addClass('disabled');
                    }
                    $('.pagination .next').attr('data-page', parseInt(images.page) + 1);

                    $('#page-number').html(parseInt(images.page) + 1 + ' / ' + parseInt(images.total_pages));
                }
            });
        };

        //Search by filename
        var searchTimeout;
        $('#search').bind('input', function () {
            var lastSearch = $(this).val();
            clearTimeout(searchTimeout);
            searchTimeout = setTimeout(function () {
                if ($('#search').val() === lastSearch) {
                    getImages();
                }
            }, 1000);

        });

        //Click on previous or next button
        $('.pagination .previous, .pagination .next').click(function () {
            if ($(this).hasClass('disabled')) {
                return;
            }
            getImages($(this).attr('data-page'));
        });
        // change number of items to display
        $('.pagination .pageSize').change(function () {
            getImages();
        });

        //Optimize an image
        bindOptimizeClick = function () {
            $('a.optimize').unbind('click').click(function (e) {
                e.preventDefault();
                var idImage = $(this).parents('tr').data('id');
                var $line = $('tr[data-id="' + idImage + '"]');

                $line.find('td[data-col="status"]').html(preloader);
                $line.find('a.action').addClass('disabled');

                $.ajax({
                    url: './ajax.php',
                    type: 'POST',
                    data: {
                        action: 'optimize',
                        id: idImage
                    },
                    success: function (data) {
                        data = JSON.parse(data);
                        if (data.status === 'success') {

                            $line.find('td[data-col="size_before"]').html(bytesToSize(data.response.size_before));
                            $line.find('td[data-col="size_after"]').html(bytesToSize(data.response.size_after));
                            $line.find('td[data-col="status"]').html(Handlebars.helpers.status('O'));

                            $line.find('a.action').html(Handlebars.helpers.optimizeBtn('O'));
                            $line.find('a.action').removeClass('optimize').addClass('revert');

                            bindOptimizeClick();
                        } else {
                            Materialize.toast(data.response, 4000, 'red darken-1');
                        }
                    },
                    complete: function () {
                        $line.find('a.action').removeClass('disabled');
                        $line.find('.preloader-wrapper').remove();
                    }
                });
            });

            $('a.revert').unbind('click').click(function (e) {
                e.preventDefault();
                var idImage = $(this).parents('tr').data('id');
                var $line = $('tr[data-id="' + idImage + '"]');

                $line.find('td[data-col="status"]').html(preloader);
                $line.find('a.action').addClass('disabled');

                $.ajax({
                    url: './ajax.php',
                    type: 'POST',
                    data: {
                        action: 'revert',
                        id: idImage
                    },
                    success: function (data) {
                        data = JSON.parse(data);
                        if (data.status === 'success') {
                            $line.find('td[data-col="api_id"]').html('');
                            $line.find('td[data-col="size_before"]').html('');
                            $line.find('td[data-col="size_after"]').html('');
                            $line.find('td[data-col="status"]').html(Handlebars.helpers.status('R'));
                            $line.find('td[data-col="expiration_date"]').html('');

                            $line.find('a.action').html(Handlebars.helpers.optimizeBtn('R'));
                            $line.find('a.action').removeClass('revert').addClass('optimize');

                            bindOptimizeClick();
                        } else {
                            Materialize.toast(data.response, 4000, 'red darken-1');
                        }
                    },
                    complete: function () {
                        $line.find('a.action').removeClass('disabled');
                        $line.find('.preloader-wrapper').remove();
                    }
                });
            });
        };

        checkOptimizationStatus = function () {
            if (window.optimizeAllInterval === undefined) {
                window.optimizeAllInterval = setInterval(function () {
                    $.ajax({
                        url: './ajax.php',
                        type: 'POST',
                        data: {
                            action: 'optimizeStatus'
                        },
                        success: function (data) {
                            data = JSON.parse(data);
                            if (data.status == 'stopped') {
                                $('#stopOptimizeAll').hide();
                                $('#optimizeAll').show();
                                clearInterval(window.optimizeAllInterval);
                                delete window.optimizeAllInterval;
                            } else {
                                $('#stopOptimizeAll span').html((parseInt(data.response.optimization_optimized) + parseInt(data.response.optimization_errors)) + ' / ' + data.response.optimization_total);
                            }
                        }
                    });
                }, 3000);
            }
        };

        bytesToSize = function (bytes) {
            if (bytes === undefined || bytes === null) {
                return '';
            }
            var sizes = {
                0: 'B',
                1: 'KB',
                2: 'MB',
                3: 'GB',
                4: 'TB',
                5: 'PB'
            }
            if (bytes === 0) {
                return '0 ' + sizes[0];
            }
            var i = parseInt(Math.floor(Math.log(bytes) / Math.log(1024)));
            rd = (bytes / Math.pow(1024, i)).toFixed(2);
            return rd + ' ' + sizes[i];
        }

        <?php if($configuration->last_sync === ''): ?>
        //If no sync already done, force it
        $('#sync').click();
        <?php else: ?>
        //Load images on page loads
        images = getImages();
        <?php endif; ?>


        <?php if($optimizationRunning): ?>
        //If no sync already done, force it
        checkOptimizationStatus();
        <?php endif; ?>

    });

</script>